@@ -40,6 +40,8 @@ def have_func_nolink(func, headers = nil, &b)
 end
  
 dir_config("odbc")
+have_header("version.h")
+have_header("ruby/version.h")
 have_header("sql.h") || begin
   puts "ERROR: sql.h not found"
   exit 1
@@ -113,9 +115,9 @@ if PLATFORM =~ /mswin32/ then
   have_func("SQLInstallerError", "odbcinst.h")
   have_func("SQLInstallerErrorW", "odbcinst.h")
 elsif PLATFORM =~ /(mingw|cygwin)/ then
-  have_library("odbc32", "")
-  have_library("odbccp32", "")
-  have_library("user32", "")
+  have_library("odbc32")
+  have_library("odbccp32")
+  have_library("user32")
   header = ["windows.h", "odbcinst.h"]
   have_func("SQLConfigDataSourceW", header)
   have_func("SQLWriteFileDSNW", header)
